@@ -17,7 +17,7 @@
 __version__ = "beta-test"
 __author__ = "Yijie Xia"
 
-from collections import OrderedDict
+from collections import OrderedDict, deque
 import os
 import numpy as np
 import types
@@ -232,6 +232,38 @@ class ResidueType(Type):
     @tail.setter
     def tail(self, atom):
         self.link["tail"] = atom
+        
+    @property
+    def head_next(self):
+        return self.link["head_next"]
+    
+    @head_next.setter
+    def head_next(self, atom):
+        self.link["head_next"] = atom
+        
+    @property
+    def tail_next(self):
+        return self.link["tail_next"]
+    
+    @tail_next.setter
+    def tail_next(self, atom):
+        self.link["tail_next"] = atom 
+    
+    @property
+    def head_length(self):
+        return self.link["head_length"]
+    
+    @head_length.setter
+    def head_length(self, atom):
+        self.link["head_length"] = atom
+        
+    @property
+    def tail_length(self):
+        return self.link["tail_length"]
+    
+    @tail_length.setter
+    def tail_length(self, atom):
+        self.link["tail_length"] = atom   
     
     @property
     def head_link_conditions(self):
@@ -250,7 +282,8 @@ class ResidueType(Type):
         self.bonded_forces = {}
         self.builded = False
         self.bonded_forces = {frc.name:[] for frc in GlobalSetting.BondedForces}
-        self.link = {"head": None, "tail": None, "head_link_conditions":[], "tail_link_conditions":[]}
+        self.link = {"head": None, "tail": None, "head_next":None, "tail_next":None, 
+        "head_length":1.5, "tail_length":1.5, "head_link_conditions":[], "tail_link_conditions":[]}
         self.connect_atoms = {}
         
     def Add_Atom(self, name, atom_type, x, y, z):
@@ -431,14 +464,23 @@ class Molecule():
     def __repr__(self):
         return "Entity of Molecule: " + self.name
     def __init__(self, name):
-        self.name = name
-        Molecule.all[name] = self
+        if type(name) == ResidueType:
+            self.name = name.name
+        else:
+            self.name = name
+        Molecule.all[self.name] = self
         self.residues = []
         self.atoms = []
         self.residue_links = []
         self.bonded_forces = []
         self.builded = False
-        
+        if type(name) == ResidueType:
+            new_residue = Residue(name)
+            for i in name.atoms:
+                new_residue.Add_Atom(i)
+            self.Add_Residue(new_residue)
+            
+            
         
     def Add_Residue(self, residue):
         self.residues.append(residue)
@@ -592,4 +634,4 @@ def Generate_New_Pairwise_Force_Type(Type_Name, properties):
 
 
 
-from . import LOAD, BUILD, IMPOSE, PROCESS
+from . import assign, LOAD, BUILD, IMPOSE, PROCESS
